{% extends "beam/base.html" %}
{% load i18n %}

{% block title %}{{ title }} | {{ block.super }}{% endblock %}

{% block content %}
    <h1>{% block heading %}{{ title }}{% endblock %}</h1>

    <p>{% translate "Your password has been set.  You may go ahead and log in now." %}</p>

    <p><a href="{{ login_url }}">{% translate 'Log in' %}</a></p>
{% endblock %}
