{% extends "beam/form.html" %}
{% load beam_tags %}

{% block body_classes %}{{ block.super }} beam-create{% if component.model %}{% get_options component.model as options %} beam-create-{{ options.app_label }}-{{ options.model_name }}{% endif %}{% endblock %}
